@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 #--------------------------------------------------------------------------------
-#www2sms.py v1.1.2
+#www2sms.py v1.1.3
 #Copyright Bjoern Olausson
 #--------------------------------------------------------------------------------
 #This program is free software; you can redistribute it and/or modify
@@ -33,7 +33,7 @@ from www2sms_gui_dialog_progress import Ui_Form_Progress
 import www2sms_providers
 
 
-VERSION = "v1.1.2"
+VERSION = "v1.1.3"
 USER = pwd.getpwuid(os.getuid())[0]
 CONFIG_DIR = "/home/%s/MyDocs/www2sms" %(USER)
 
@@ -145,7 +145,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
 	# Function wich generates a nice sorted list for all contacts.
 	def get_contacts(self):
 		# Regular expression to find Cellular phone numbers in the vCard
-		re_tel = re.compile("TEL;.*TYPE=CELL.*")
+		re_tel = re.compile("^TEL;.*CELL.*:")
 
 		# Not usefull right now...
 		name_attributes = [
@@ -210,7 +210,6 @@ class MainWindow(QMainWindow, Ui_MainWindow):
 			vcard = econtact.get_vcard_string()
 			for line in vcard.split('\n'):
 				if re_tel.search(line):
-					#print line
 					number = line.split(':')[1].strip()
 					contact_and_numbers.extend([number.decode('utf-8')])
 			# Now store the list of contact with all its numbers in in another list
